# PrinceFFInfo

A simple Python package to fetch Free Fire account information.

## Installation

```bash
pip install princeffinfo

Usage

import princeffinfo

account_info = princeffinfo.input("12345678")
print(account_info)